import { select, range } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;

// create a new SVG element and append it to the body of the document
// set width and height
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// less common
// // horizontal rectangles
// const n = 100;
// const marks = [];
// for (let i = 0; i < n; i++) {
//   marks.push({
//     y: i * 20,
//     width: width,
//     height: 10,
//     mask: 'url(#circle-mask)',
//   });
// }

// // d3 data join
// svg
//   .selectAll('rect') // select all rectangles on the page
//   .data(marks) // create one rectangle for each mark
// 	.join('rect')
// 	.attr('y', (d) => d.y)
// 	.attr('width', (d) => d.width)
// 	.attr('height', (d) => d.height)
// 	.attr('mask', (d) => d.mask);

// more common
// horizontal rectangles
const n = 100;
svg //.append('g') - instead of classes, could use group elements; selection only acts within group elements
  .selectAll('rect.horizontal') // select all rectangles on the page
  .data(range(n)) // create one rectangle for each mark
  .join('rect')
  .attr('y', (d) => d * 20) // function - value changes for each object
  .attr('width', width) // constant value
  .attr('height', 10)
  .attr('class', 'horizontal')
  .attr('mask', 'url(#circle-mask)');

// vertical rectangles
svg //.append('g')
  .selectAll('rect.vertical') // select all rectangles on the page - at this point, it is empty
  .data(range(n)) // empty selection from SelectAll is associated with this array
  .join('rect') // append a new rectangle that the attributes will be set on in the DOM element
  .attr('x', (d) => d * 20) // function - value changes for each object
  .attr('width', 10) // constant value
  .attr('height', height)
  .attr('class', 'vertical')
  .attr('mask', 'url(#circle-mask-2)');

// mask element
const mask = svg
  .append('mask')
  .attr('id', 'circle-mask');

// rectangle mask
mask
  .append('rect')
  .attr('width', width)
  .attr('height', height)
  .attr('fill', 'black');

// circle mask
mask
  .append('circle')
  .attr('cx', width / 2)
  .attr('cy', height / 2)
  .attr('r', 200)
  .attr('fill', 'white');

// mask2 element - inverted
const mask2 = svg
  .append('mask')
  .attr('id', 'circle-mask-2');

// rectangle mask
mask2
  .append('rect')
  .attr('width', width)
  .attr('height', height)
  .attr('fill', 'white');

// circle mask
mask2
  .append('circle')
  .attr('cx', width / 2)
  .attr('cy', height / 2)
  .attr('r', 200)
  .attr('fill', 'black');
